@@ -220,7 +220,15 @@
 #include "token_info-5.23.8.h"
 #elif PERL_VERSION == 24 && PERL_SUBVERSION == 0
 #include "token_info-5.24.0.h"
-#elif PERL_VERSION > 24 || (PERL_VERSION == 24 && PERL_SUBVERSION > 0)
+#elif PERL_VERSION == 24
+#include "token_info-5.24.0.h"
+#elif PERL_VERSION == 25 && PERL_SUBVERSION == 0
+#include "token_info-5.25.0.h"
+#elif PERL_VERSION == 25 && PERL_SUBVERSION == 1
+#include "token_info-5.25.1.h"
+#elif PERL_VERSION == 25 && PERL_SUBVERSION == 2
+#include "token_info-5.25.2.h"
+#elif PERL_VERSION > 25 || (PERL_VERSION == 25 && PERL_SUBVERSION > 2)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
